@@ -1,19 +1,36 @@
 #' V-Fold Cross-Validation
 #'
-#' V-fold cross-validation randomly splits the data into V groups of roughly equal size (called "folds"). A resample of the analysis data consisted of V-1 of the folds while the assessment set contains the final fold. In basic V-fold cross-validation (i.e. no repeats), the number of resamples is equal to V.
-
+#' V-fold cross-validation randomly splits the data into V groups of roughly
+#'  equal size (called "folds"). A resample of the analysis data consisted of
+#'  V-1 of the folds while the assessment set contains the final fold. In basic
+#'  V-fold cross-validation (i.e. no repeats), the number of resamples is equal
+#'  to V.
 #' @details
-#' The `strata` argument causes the random sampling to be conducted *within the stratification variable*. The can help ensure that the number of data points in the analysis data is equivalent to the proportions in the original data set.
-#'
-#' When more than one repeat is requested, the basic V-fold cross-validation is conducted each time. For example, if three repeats are used with `v = 10`, there are a total of 30 splits which as three groups of 10 that are generated separately.
-#'
+#' The `strata` argument causes the random sampling to be conducted *within
+#'  the stratification variable*. The can help ensure that the number of data
+#'  points in the analysis data is equivalent to the proportions in the original
+#'  data set.
+#' When more than one repeat is requested, the basic V-fold cross-validation
+#'  is conducted each time. For example, if three repeats are used with `v =
+#'  10`, there are a total of 30 splits which as three groups of 10 that are
+#'  generated separately.
 #' @param data A data frame.
 #' @param v The number of partitions of the data set.
 #' @param repeats The number of times to repeat the V-fold partitioning.
-#' @param strata A variable that is used to conduct stratified sampling to create the folds. This should be a single character value.
+#' @param strata A variable that is used to conduct stratified sampling to
+#'  create the folds. This could be a single character value or a variable name
+#'  that corresponds to a variable that exists in the data frame.
+#' @param breaks A single number giving the number of bins desired to stratify
+#'  a numeric stratification variable.
 #' @param ... Not currently used.
 #' @export
-#' @return  A tibble with classes `vfold_cv`, `rset`, `tbl_df`, `tbl`, and `data.frame`. The results include a column for the data split objects and one or more identification variables. For a single repeats, there will be one column called `id` that has a character string with the fold identifier. For repeats, `id` is the repeat number and an additional column called `id2` that contains the fold information (within repeat).
+#' @return A tibble with classes `vfold_cv`, `rset`, `tbl_df`, `tbl`, and
+#'  `data.frame`. The results include a column for the data split objects and
+#'  one or more identification variables. For a single repeats, there will be
+#'  one column called `id` that has a character string with the fold identifier.
+#'  For repeats, `id` is the repeat number and an additional column called `id2`
+#'  that contains the fold information (within repeat).
+
 #' @examples
 #' vfold_cv(mtcars, v = 10)
 #' vfold_cv(mtcars, v = 10, repeats = 2)
@@ -36,13 +53,26 @@
 #'           dat <- as.data.frame(x)$Species
 #'           mean(dat == "virginica")
 #'         })
+#'
+#' set.seed(13)
+#' folds3 <- vfold_cv(iris2, strata = "Petal.Length", breaks = 6, v = 5)
+#' map_dbl(folds3$splits,
+#'         function(x) {
+#'           dat <- as.data.frame(x)$Species
+#'           mean(dat == "virginica")
+#'         })
 #' @export
-vfold_cv <- function(data, v = 10, repeats = 1, strata = NULL, ...) {
+vfold_cv <- function(data, v = 10, repeats = 1, strata = NULL, breaks = 4, ...) {
+
+  if(!missing(strata)) {
+    strata <- tidyselect::vars_select(names(data), !!enquo(strata))
+    if(length(strata) == 0) strata <- NULL
+  }
 
   strata_check(strata, names(data))
 
   if (repeats == 1) {
-    split_objs <- vfold_splits(data = data, v = v, strata = strata)
+    split_objs <- vfold_splits(data = data, v = v, strata = strata, breaks = breaks)
   } else {
     for (i in 1:repeats) {
       tmp <- vfold_splits(data = data, v = v, strata = strata)
@@ -76,10 +106,7 @@ vfold_complement <- function(ind, n) {
        assessment = ind)
 }
 
-#' @importFrom tibble tibble
-#' @importFrom purrr map
-#' @importFrom dplyr bind_rows
-vfold_splits <- function(data, v = 10, strata = NULL) {
+vfold_splits <- function(data, v = 10, strata = NULL, breaks = 4) {
   if (!is.numeric(v) || length(v) != 1)
     stop("`v` must be a single integer.", call. = FALSE)
 
@@ -90,7 +117,8 @@ vfold_splits <- function(data, v = 10, strata = NULL) {
     indices <- split(idx, folds)
   } else {
     stratas <- tibble::tibble(idx = 1:n,
-                              strata = make_strata(getElement(data, strata)))
+                              strata = make_strata(getElement(data, strata),
+                                                   breaks = breaks))
     stratas <- split(stratas, stratas$strata)
     stratas <- purrr::map(stratas, add_vfolds, v = v)
     stratas <- dplyr::bind_rows(stratas)
@@ -113,5 +141,5 @@ add_vfolds <- function(x, v) {
 print.vfold_cv <- function(x, ...) {
   cat("# ", pretty(x), "\n")
   class(x) <- class(x)[!(class(x) %in% c("vfold_cv", "rset"))]
-  print(x)
+  print(x, ...)
 }
